Hello!

This repo holds the `v1.3.0-dev1` in-development version of the Common Workflow Language standard and the history of its development.

You can render this draft specification using the `render.bash` script.
